| Title: | Fast plots of svg graphics in R |
|---|---|
| Description: | What the package does (one paragraph). |
| Authors: | mark padgham [aut, cre] |
| Maintainer: | mark padgham <[email protected]> |
| License: | GPL-3 |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-13 06:44:49 UTC |
| Source: | https://github.com/hypertidy/svgplotr |
Make a single trail from a bunch of random connected edges
getlines(n = 1000, xylim = 1000)getlines(n = 1000, xylim = 1000)
n |
Number of edges |
xylim |
Maximal x and y values |
A data.frame of randomly wandering edges
Get a bunch of random points along with colour attributes
getpoints(n = 1000, xylim = 1000)getpoints(n = 1000, xylim = 1000)
n |
Number of points |
xylim |
Maximal x and y values |
A data.frame of random points
Plot line data as html-formatted svg file.
svgplot_lines(dat, filename, html = TRUE)svgplot_lines(dat, filename, html = TRUE)
dat |
A test |
filename |
Name of |
html |
If |
Nothing
Plot point data as html-formatted svg file.
svgplot_points(dat, filename, html = TRUE)svgplot_points(dat, filename, html = TRUE)
dat |
A test |
filename |
Name of |
html |
If |
Nothing